@@ -29,8 +29,8 @@ function log()
 # get correct version of odo from upstream
 # toolsJson="https://github.com/redhat-developer/vscode-openshift-tools/raw/master/src/tools.json"
 # curl -sSL $toolsJson -o - |   jq ".odo.platform.linux.url" -r | sed -r -e "s#.+/clients/odo/v(.+)/odo.+#\1#"
-ODO_VERSION="v1.2.5"
-KUBECTL_VERSION="v1.18.3" # see https://github.com/kubernetes/kubernetes/releases/ or $(curl -s https://storage.googleapis.googleapis.com/kubernetes-release/release/stable.txt)
+ODO_VERSION="v2.0.1"
+KUBECTL_VERSION="v1.18.10" # see https://github.com/kubernetes/kubernetes/releases/ or $(curl -s https://storage.googleapis.googleapis.com/kubernetes-release/release/stable.txt)
 
 # update Dockerfile to record versions we expect
 sed Dockerfile \
@@ -56,7 +56,7 @@ if [[ $(diff -U 0 --suppress-common-lines -b Dockerfile.2 Dockerfile) ]] || [[ $
   rhpkg new-sources bin.tgz
 	log "[INFO] Commit new sources"
   COMMIT_MSG="odo ${ODO_VERSION}, kubectl ${KUBECTL_VERSION}"
-	if [[ $(git commit -s -m "[get sources] ${COMMIT_MSG}" sources Dockerfile) == *"nothing to commit, working tree clean"* ]]; then 
+	if [[ $(git commit -s -m "[get sources] ${COMMIT_MSG}" sources Dockerfile .gitignore) == *"nothing to commit, working tree clean"* ]]; then 
 		log "[INFO] No new sources, so nothing to build."
 	elif [[ ${doRhpkgContainerBuild} -eq 1 ]]; then
 		log "[INFO] Push change:"
@@ -64,9 +64,9 @@ if [[ $(diff -U 0 --suppress-common-lines -b Dockerfile.2 Dockerfile) ]] || [[ $
   fi
   if [[ ${doRhpkgContainerBuild} -eq 1 ]]; then
     echo "[INFO] Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
-    tmpfile=`mktemp` && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
+    tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
     taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
-    ERRORS="$(egrep "image build failed" $tmpfile)" && rm -f $tmpfile
+    ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
     if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
 
 $ERRORS
@@ -76,9 +76,9 @@ $ERRORS
 else
 	if [[ ${forceBuild} -eq 1 ]]; then
     echo "[INFO] Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
-    tmpfile=`mktemp` && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
+    tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
     taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
-    ERRORS="$(egrep "image build failed" $tmpfile)" && rm -f $tmpfile
+    ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
     if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
 
 $ERRORS
